@@ -19,7 +19,7 @@ private $temporary_folder;
 
   }
 
-  
+
   /**
   * Test extraction of all sorts of information from USFM code
   * Test basic formatting into OpenDocument.
@@ -47,6 +47,7 @@ $usfm = <<<'EOD'
 \v 2 Text chapter 2
 EOD;
     $filter_text = new Filter_Text ("");
+    $filter_text->odf_text_standard = new Odf_Text;
     $filter_text->addUsfmCode ($usfm);
     $filter_text->run ("Standard");
     // Check that it finds the running headers.
@@ -95,10 +96,11 @@ $usfm = <<<'EOD'
 \xxx Unknown markup
 EOD;
     $filter_text = new Filter_Text ("");
+    $filter_text->odf_text_standard = new Odf_Text;
     $filter_text->addUsfmCode ($usfm);
     $filter_text->run ("Standard");
     @unlink ("/tmp/TextTest2.odt");
-    $filter_text->odf_text_standard->save("/tmp/TextTest2.odt");
+    $filter_text->odf_text_standard->save ("/tmp/TextTest2.odt");
     exec ("odt2txt /tmp/TextTest2.odt", $output, $return_var);
     $this->assertEquals (array ("", "Genesis 1", "=========", "", "Text Genesis 1", "", "Genesis 2", "=========", "", "Text Genesis 2", "", "Matthew 1", "=========", "", "Text Matthew 1", "", "Matthew 2", "=========", "", "Text Matthew 2", ""), $output);
     $this->assertEquals (array ('Genesis 0:0 Text encoding indicator not supported. Encoding is always in UTF8: \ide XYZ',
@@ -124,6 +126,7 @@ $usfm = <<<'EOD'
 \v 5 Verse Five.
 EOD;
     $filter_text = new Filter_Text ("");
+    $filter_text->odf_text_standard = new Odf_Text;
     $filter_text->addUsfmCode ($usfm);
     $filter_text->run ("Standard");
     @unlink ("/tmp/TextTest3.odt");
@@ -144,6 +147,7 @@ $usfm = <<<'EOD'
 \v 1 Text 1\x + \xt Isa. 1.1.\x*\x - \xt Isa. 2.2.\x*\x + \xt Isa. 3.3.\x*, text 2\f + \fk Word1: \fl Heb. \fq Explanation1.\f*\f + \fk Word2: \fl Heb. \fq Explanation2.\f*, text3.\f + \fk Test: \fl Heb. \fq Note at the very end.\f*
 EOD;
     $filter_text = new Filter_Text ("");
+    $filter_text->odf_text_standard = new Odf_Text;
     $filter_text->addUsfmCode ($usfm);
     $filter_text->run ("Standard");
     @unlink ("/tmp/TextTest4.odt");
@@ -154,7 +158,150 @@ EOD;
   }
 
 
+  public function testClearTextExport1 ()
+  {
+$usfm = <<<'EOD'
+\id GEN
+\h Genesis
+\toc2 Genesis
+\mt2 The book of
+\mt Genesis
+\c 1
+\p
+\v 1 In the be\x + \xt Isa. 1.1.\x*\x - \xt Isa. 2.2.\x*ginning, God created\f + \fk Word1: \fl Heb. \fq Explanation1.\f*\f + \fk Word2: \fl Heb. \fq Explanation2.\f* the heavens and the earth.\f + \fk Test: \fl Heb. \fq Note at the very end.\f*
+EOD;
+    $filter_text = new Filter_Text ("");
+    $filter_text->text_text = new Text_Text ();
+    $filter_text->addUsfmCode ($usfm);
+    $filter_text->run ("Standard");
+    $output = $filter_text->text_text->get ();
+$standard = <<<'EOD'
+The book of
+Genesis
+1
+1 In the beginning, God created the heavens and the earth.
+EOD;
+    $this->assertEquals ($output, $standard);
+  }
+
+
+  public function testClearTextExport2 ()
+  {
+$usfm = <<<'EOD'
+\id GEN
+\c 1
+\p
+\v 1 Chapter 1, verse one.
+\v 2 Verse two.
+\c 2
+\p
+\v 1 Chapter 2, verse one.
+\v 2 Verse two.
+EOD;
+    $filter_text = new Filter_Text ("");
+    $filter_text->text_text = new Text_Text ();
+    $filter_text->addUsfmCode ($usfm);
+    $filter_text->run ("Standard");
+    $output = $filter_text->text_text->get ();
+$standard = <<<'EOD'
+1
+1 Chapter 1, verse one. 2 Verse two.
+2
+1 Chapter 2, verse one. 2 Verse two.
+EOD;
+    $this->assertEquals ($output, $standard);
+  }
+
+
+  public function testVersesHeadings ()
+  {
+$usfm = <<<'EOD'
+\id GEN
+\c 1
+\p
+\v 1 Verse one.
+\v 2 Verse two.
+\s Heading one
+\v 3 Verse three
+\p
+\s Heading two
+\v 4 Verse four.
+\v 5 Verse five.
+\c 2
+\s Heading three
+\v 1 Verse one.
+EOD;
+    $filter_text = new Filter_Text ("");
+    $filter_text->initializeHeadingsAndTextPerVerse ();
+    $filter_text->addUsfmCode ($usfm);
+    $filter_text->run ("Standard");
+    $output = $filter_text->verses_headings;
+    $this->assertEquals ($output, array (2 => "Heading one", 3 => "Heading two", 0 => "Heading three"));
+  }
+
+
+  public function testVersesTextOne ()
+  {
+$usfm = <<<'EOD'
+\id GEN
+\c 1
+\p
+\v 2 Verse\x + \xt Isa. 1.1.\x* two.
+\v 3 Verse three\x + \xt Isa. 1.1.\x*.
+\s Heading one
+\p
+\v 4 Verse four.
+\p
+\s Heading two
+\p
+\v 5 Verse five.
+\v 6 Verse six.
+\c 2
+\s Heading three
+\p
+\v 1 Verse one\x + \xt Isa. 1.1.\x*.
+EOD;
+    $filter_text = new Filter_Text ("");
+    $filter_text->initializeHeadingsAndTextPerVerse ();
+    $filter_text->addUsfmCode ($usfm);
+    $filter_text->run ("Standard");
+    $output = $filter_text->getVersesText ();
+    $standard = array (
+      2 => "Verse two.",
+      3 => "Verse three.",
+      4 => "Verse four.",
+      5 => "Verse five.",
+      6 => "Verse six.",
+      1 => "Verse one."
+    );
+    $this->assertEquals ($standard, $output);
+  }
+
+
+  public function testVersesTextTwo ()
+  {
+$usfm = <<<'EOD'
+\c 15
+\s Heading
+\p
+\v 1 He said:
+\p I will sing to the Lord.
+\v 2 The Lord is my strength.
+EOD;
+    $filter_text = new Filter_Text ("");
+    $filter_text->initializeHeadingsAndTextPerVerse ();
+    $filter_text->addUsfmCode ($usfm);
+    $filter_text->run ("Standard");
+    $output = $filter_text->getVersesText ();
+    $standard = array (
+      1 => "He said: I will sing to the Lord.",
+      2 => "The Lord is my strength."
+    );
+    $this->assertEquals ($standard, $output);
+  }
+
+
 }
 
 
-?>
\ No newline at end of file
+?>
