@@ -22,7 +22,7 @@ file_put_contents ($temporal_file_name, "contents");
 // Add this file.
 $command = "cd $directory; git add . 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 if ($exit_code == 0) {
   echo gettext ("Ok: Local addition was made successfully.");
 } else {
@@ -35,7 +35,7 @@ echo gettext ("Step: Committing the above changes locally") . "\n";
 // Commit the above locally.
 $command = "cd $directory; git commit -a -m write-test 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 // Exit code can be 1 in case there was nothing to commit.
 if (($exit_code == 0) || ($exit_code == 1)) {
   echo gettext ("Ok: Local commit was made successfully.");
@@ -51,7 +51,7 @@ echo gettext ("Step: Pulling changes from the remote repository") . "\n";
 // because in such cases the exit code is undefined.
 $command = "cd $directory; git pull 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 echo gettext ("Ok: Changes were pulled from the repository successfully.");
 echo "\n";
 
@@ -61,7 +61,7 @@ echo gettext ("Step: Pushing changes to the remote repository") . "\n";
 // Notice the --all switch needed when the remote repository is empty.
 $command = "cd $directory; git push --all 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 if ($exit_code == 0) {
   echo gettext ("Ok: Changes were pushed to the repository successfully.");
 } else {
@@ -75,7 +75,7 @@ echo gettext ("Step: Removing the temporal file from the local repository") . "\
 unlink ($temporal_file_name);
 $command = "cd $directory; git commit -a -m write-test 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 if ($exit_code == 0) {
   echo gettext ("Ok: The temporal file was removed from the local repository successfully.");
 } else {
@@ -88,7 +88,7 @@ echo gettext ("Step: Pushing the changes to the remote repository") . "\n";
 // Push changes to the remote repository.
 $command = "cd $directory; git push 2>&1";
 echo "$command\n";
-passthru ($command, &$exit_code);
+passthru ($command, $exit_code);
 if ($exit_code == 0) {
   echo gettext ("Ok: Changes were pushed to the remote repository successfully.");
 } else {
