@@ -22,11 +22,6 @@ $database_logs = Database_Logs::getInstance ();
 $database_logs->optimize();
 
 
-// The versions table.
-$database_versions = Database_Versions::getInstance ();
-$database_versions->optimize ();
-
-
 // The user table.
 $database_users = Database_Users::getInstance();
 $database_users->optimize ();
@@ -117,8 +112,13 @@ $database_git = Database_Git::getInstance();
 $database_git->optimize();
 
 
+// The logger table.
+$database_logger = Database_Logger::getInstance ();
+$database_logger->optimize();
+
+
 // Done.
 message_information ("Ready");
 
 
-?>
\ No newline at end of file
+?>
