@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ class Bootstrap
     // Set the include path, where to look for included files.
     $this->bibledit_root_folder = dirname (dirname(__FILE__));
     include $this->bibledit_root_folder . "/paths/paths.php";
-    $include_path = get_include_path () . ":" . $this->bibledit_root_folder . ":" . dirname ($zendPath) . ":" . $smartyPath;
+    $include_path = get_include_path () . ":" . $this->bibledit_root_folder . ":" . dirname ($zendPath);
     set_include_path ($include_path);
     ini_set('include_path', $include_path); 
     
@@ -120,4 +120,4 @@ class Bootstrap
 }
 
 
-?>
\ No newline at end of file
+?>
