@@ -3,15 +3,8 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (CONSULTANT_LEVEL);
 $smarty = new Smarty_Bibledit (__FILE__);
-
 $database_config_user = Database_Config_User::getInstance();
 $bible = $database_config_user->getBible();
 $smarty->assign ("bible", $bible);
-
-$plugin_enumerator = Plugins_Enumerator::getInstance();
-$plugins = $plugin_enumerator->getMenuPlugins ("consultations");
-$smarty->assign ("plugins", $plugins);
-
 $smarty->display("index.tpl");
-
-?>
\ No newline at end of file
+?>
