@@ -168,7 +168,65 @@ class Database_Bibles
     $chapter_text = Database_SQLInjection::no ($chapter_text);
     $query = "DELETE FROM bible_data WHERE bible = $bible_id AND book = $book AND chapter = $chapter_number;";
     $database_instance->runQuery ($query);
-    $query = "INSERT INTO bible_data VALUES (NULL, $bible_id, $book, $chapter_number, '$chapter_text');";
+    $query = "INSERT INTO bible_data VALUES (NULL, $bible_id, $book, $chapter_number, '$chapter_text', NULL, NULL);";
+    $database_instance->runQuery ($query);
+    // Update search fields. 
+    $this->updateSearchFields ($name, $book, $chapter_number);
+  }
+
+
+  /*
+   * Updates the search fields for one chapter in Bible $name.
+   */
+  public function updateSearchFields ($name, $book, $chapter)
+  {
+    // Extract clean text from the USFM.
+    $filter_text = new Filter_Text ("");
+    $filter_text->initializeHeadingsAndTextPerVerse ();
+    $usfm = $this->getChapter ($name, $book, $chapter);
+    $filter_text->addUsfmCode ($usfm);
+    $database_config_user = Database_Config_User::getInstance ();
+    $stylesheet = $database_config_user->getStylesheet ();
+    $filter_text->run ($stylesheet);
+
+    // The clean text to search on.
+    $searchText = array ();
+
+    // First add the clean verse texts.
+    $texts = $filter_text->getVersesText ();
+    foreach ($texts as $verse => $text) {
+      if (isset ($searchText [$verse])) {
+        $searchText [$verse] .= "$text\n";
+      } else {
+        $searchText [$verse] = "$verse $text\n";
+      }
+    }
+    
+    // Secondly add the clean headings.
+    $headings = $filter_text->verses_headings;
+    foreach ($headings as $verse => $heading) {
+      if (isset ($searchText [$verse])) {
+        $searchText [$verse] .= "$heading\n";
+      } else {
+        $searchText [$verse] = "$verse $heading\n";
+      }
+    }
+
+    // Sort the clean text on verse number.
+    ksort ($searchText);
+
+    // Create search texts for the columns "forward"  and "reverse"
+    $forward = implode ("\n", $searchText);
+    $reverse = Filter_String::reverse ($forward);
+
+    // Store the search data in the table.
+    $database_instance = Database_Instance::getInstance();
+    $bible = $this->getID ($name);
+    $book = Database_SQLInjection::no ($book);
+    $chapter = Database_SQLInjection::no ($chapter);
+    $forward = Database_SQLInjection::no ($forward);
+    $reverse = Database_SQLInjection::no ($reverse);
+    $query = "UPDATE bible_data SET forward = '$forward', reverse = '$reverse' WHERE bible = $bible AND book = $book AND chapter = $chapter;";
     $database_instance->runQuery ($query);
   }
   
@@ -301,7 +359,7 @@ class Database_Bibles
     $database_instance = Database_Instance::getInstance();
     $book = Database_SQLInjection::no ($book);
     $chapter = Database_SQLInjection::no ($chapter);
-    $query = "INSERT INTO bible_diff SELECT * FROM bible_data WHERE bible = $bible AND book = $book AND chapter = $chapter;";
+    $query = "INSERT INTO bible_diff SELECT id, bible, book, chapter, data FROM bible_data WHERE bible = $bible AND book = $book AND chapter = $chapter;";
     $database_instance->runQuery ($query);
   }
 
@@ -430,6 +488,83 @@ class Database_Bibles
   }
 
 
+  /**
+  * Searches the text of the Bibles.
+  * Returns an array of ids of the relevant chapters.
+  * If $limit is non-NULL, it indicates the starting limit for the selection.
+  * $search: Contains the text to search for.
+  */
+  public function searchText ($search, $limit = NULL)
+  {
+    $ids = array ();
+
+    $search = str_replace (",", "", $search);
+    $forward = Database_SQLInjection::no ($search);
+    $reverse = Database_SQLInjection::no (Filter_String::reverse ($search));
+
+    $query = " SELECT id , ";
+    // Matches in natural language mode have the highest relevance.
+    $query .= " (MATCH (forward) AGAINST ('$forward' IN NATURAL LANGUAGE MODE) * 10) ";
+    $query .= " + ";
+    // Matches in phrase search have higher relevance.
+    $query .= " (MATCH (forward) AGAINST ('\"$forward\"' IN BOOLEAN MODE) * 5) ";
+    $query .= " + ";
+    // Prefix and suffix wildcards to the search words and search in boolean mode.
+    $query .= " (MATCH (forward) AGAINST ('$forward*' IN BOOLEAN MODE)) + (MATCH (reverse) AGAINST ('$reverse*' IN BOOLEAN MODE) * 1) ";
+    // Create relevance column to sort on.
+    $query .= " AS relevance ";
+
+    $query .= " FROM bible_data WHERE ";
+
+    $query .= " (MATCH (forward) AGAINST ('$forward*' IN BOOLEAN MODE)) OR (MATCH (reverse) AGAINST ('$reverse*' IN BOOLEAN MODE)) ";
+
+    // Notes get ordered on relevance of search hits.
+    $query .= " ORDER BY relevance DESC ";
+
+    // Optionally limit the number of hits.
+    if (is_numeric ($limit)) {
+      $limit = Database_SQLInjection::no ($limit);
+      $query .= " LIMIT $limit, 50 ";
+    }
+
+    $query .= ";";
+
+    $server = Database_Instance::getInstance ();
+    $result = $server->runQuery ($query);
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $id = $row[0];
+      $ids []= $id;
+    }
+
+    return $ids;
+  }
+  
+  
+  /*
+   * Returns an array with the bible, book and chapter of arecord $id.
+   */
+  public function getBibleBookChapter ($id)
+  {
+    $database_instance = Database_Instance::getInstance();
+    $id = Database_SQLInjection::no ($id);
+    $query = "SELECT bible, book, chapter FROM bible_data WHERE id = $id;";
+    $result = $database_instance->runQuery ($query);
+    return $result->fetch_assoc ();
+  }
+
+
+  public function getSearchField ($id)
+  {
+    $database_instance = Database_Instance::getInstance();
+    $id = Database_SQLInjection::no ($id);
+    $query = "SELECT forward FROM bible_data WHERE id = $id;";
+    $result = $database_instance->runQuery ($query);
+    $row = $result->fetch_row();
+    return $row[0];
+  }
+
+
 }
 
 
