@@ -75,203 +75,196 @@ class Database_Config_General
   }
   public function setSiteMailName ($value) {
     $this->setValue ("site-mail-name", $value);
-  }   
+  }
 
   public function getSiteMailAddress() {
     return $this->getValue ("site-mail-address", "");
   }
   public function setSiteMailAddress ($value) {
     $this->setValue ("site-mail-address", $value);
-  }   
+  }
 
   public function getMailStorageHost() {
     return $this->getValue ("mail-storage-host", "");
   }
   public function setMailStorageHost ($value) {
     $this->setValue ("mail-storage-host", $value);
-  }   
+  }
 
   public function getMailStorageUsername() {
     return $this->getValue ("mail-storage-username", "");
   }
   public function setMailStorageUsername ($value) {
     $this->setValue ("mail-storage-username", $value);
-  }   
+  }
 
   public function getMailStoragePassword() {
     return $this->getValue ("mail-storage-password", "");
   }
   public function setMailStoragePassword ($value) {
     $this->setValue ("mail-storage-password", $value);
-  }   
+  }
 
   public function getMailStorageSecurity() {
     return $this->getValue ("mail-storage-security", "");
   }
   public function setMailStorageSecurity ($value) {
     $this->setValue ("mail-storage-security", $value);
-  }   
+  }
 
   public function getMailStoragePort() {
     return $this->getValue ("mail-storage-port", "");
   }
   public function setMailStoragePort ($value) {
     $this->setValue ("mail-storage-port", $value);
-  }   
+  }
 
   public function getMailSendHost() {
     return $this->getValue ("mail-send-host", "");
   }
   public function setMailSendHost ($value) {
     $this->setValue ("mail-send-host", $value);
-  }   
+  }
 
   public function getMailSendAuthentication() {
     return $this->getValue ("mail-send-authentication", "");
   }
   public function setMailSendAuthentication ($value) {
     $this->setValue ("mail-send-authentication", $value);
-  }   
+  }
 
   public function getMailSendUsername() {
     return $this->getValue ("mail-send-username", "");
   }
   public function setMailSendUsername ($value) {
     $this->setValue ("mail-send-username", $value);
-  }   
+  }
 
   public function getMailSendPassword() {
     return $this->getValue ("mail-send-password", "");
   }
   public function setMailSendPassword ($value) {
     $this->setValue ("mail-send-password", $value);
-  }   
+  }
 
   public function getMailSendSecurity() {
     return $this->getValue ("mail-send-security", "");
   }
   public function setMailSendSecurity ($value) {
     $this->setValue ("mail-send-security", $value);
-  }   
+  }
 
   public function getMailSendPort() {
     return $this->getValue ("mail-send-port", "");
   }
   public function setMailSendPort ($value) {
     $this->setValue ("mail-send-port", $value);
-  }   
+  }
 
   public function getTimerMinute() {
     return $this->getValue ("timer-minute", "");
   }
   public function setTimerMinute ($value) {
     $this->setValue ("timer-minute", $value);
-  }   
-
-  public function getTimerFiveMinutes() {
-    return $this->getValue ("timer-five-minutes", "");
   }
-  public function setTimerFiveMinutes ($value) {
-    $this->setValue ("timer-five-minutes", $value);
-  }   
 
   public function getPublicSshKey() {
     return $this->getValue ("public-ssh-key", "");
   }
   public function setPublicSshKey ($value) {
     $this->setValue ("public-ssh-key", $value);
-  }   
+  }
 
   public function getPrivateSshKey() {
     return $this->getValue ("private-ssh-key", "");
   }
   public function setPrivateSshKey ($value) {
     $this->setValue ("private-ssh-key", $value);
-  }   
+  }
 
   public function getTimezone() {
     return $this->getValue ("timezone", "UTC");
   }
   public function setTimezone ($value) {
     $this->setValue ("timezone", $value);
-  }   
+  }
 
   public function getBackupFile() {
     return $this->getValue ("backup-file", "");
   }
   public function setBackupFile ($value) {
     $this->setValue ("backup-file", $value);
-  }   
+  }
 
   public function getTimerBackup() {
     return $this->getValue ("timer-backup", "");
   }
   public function setTimerBackup ($value) {
     $this->setValue ("timer-backup", $value);
-  }   
+  }
 
   public function getTimerDiff() {
     return $this->getValue ("timer-diff", "");
   }
   public function setTimerDiff ($value) {
     $this->setValue ("timer-diff", $value);
-  }   
+  }
 
   public function getTimerExports() {
     return $this->getValue ("timer-exports", "");
   }
   public function setTimerExports ($value) {
     $this->setValue ("timer-exports", $value);
-  }   
+  }
 
   public function getTimerSendReceive() {
     return $this->getValue ("timer-send-receive", "");
   }
   public function setTimerSendReceive ($value) {
     $this->setValue ("timer-send-receive", $value);
-  }   
+  }
 
   public function getSiteURL() {
     return $this->getValue ("site-url", "");
   }
   public function setSiteURL ($value) {
     $this->setValue ("site-url", $value);
-  }   
+  }
 
   public function getExportedBibles() {
     return $this->getList ("exported-bibles", "");
   }
   public function setExportedBibles ($value) {
     $this->setList ("exported-bibles", $value);
-  }   
+  }
 
   public function getExportStylesheet() {
     return $this->getValue ("export-stylesheet", "Standard");
   }
   public function setExportStylesheet ($value) {
     $this->setValue ("export-stylesheet", $value);
-  }   
+  }
 
   public function getExportChapterDropCaps() {
     return $this->getValue ("export-chapter-drop-caps", 0);
   }
   public function setExportChapterDropCaps ($value) {
     $this->setValue ("export-chapter-drop-caps", $value);
-  }   
+  }
 
   public function getHyphenationFirstSet() {
     return $this->getValue ("hyphenation-first-set", "");
   }
   public function setHyphenationFirstSet ($value) {
     $this->setValue ("hyphenation-first-set", $value);
-  }   
+  }
 
   public function getHyphenationSecondSet() {
     return $this->getValue ("hyphenation-second-set", "");
   }
   public function setHyphenationSecondSet ($value) {
     $this->setValue ("hyphenation-second-set", $value);
-  }   
+  }
 
   public function getPageWidth () {
     return $this->getValue ("page-width", 210);
@@ -327,22 +320,91 @@ class Database_Config_General
   }
   public function setSiteLanguage ($value) {
     $this->setValue ("site-language", $value);
-  }   
-
-  public function getTimerSearch () {
-    return $this->getValue ("timer-search", "");
   }
-  public function setTimerSearch ($value) {
-    $this->setValue ("timer-search", $value);
-  }   
 
-  public function getSearchDaemonPort () {
-	// Default port number for the Sphinx search daemon.
-    return $this->getValue ("search-daemon-port", "9312");
+  public function getTimerChecks () {
+    return $this->getValue ("timer-checks", "");
+  }
+  public function setTimerChecks ($value) {
+    $this->setValue ("timer-checks", $value);
+  }
+
+  public function getCheckedBibles () {
+    return $this->getList ("checked-bibles", "");
+  }
+  public function setCheckedBibles ($value) {
+    $this->setList ("checked-bibles", $value);
+  }
+
+  public function getCheckDoubleSpacesUsfm () {
+    return $this->getValue ("double-spaces-usfm", "");
+  }
+  public function setCheckDoubleSpacesUsfm ($value) {
+    $this->setValue ("double-spaces-usfm", $value);
+  }
+
+  public function getCheckFullStopInHeadings () {
+    return $this->getValue ("full-stop-headings", "");
+  }
+  public function setCheckFullStopInHeadings ($value) {
+    $this->setValue ("full-stop-headings", $value);
+  }
+
+  public function getCheckSpaceBeforePunctuation () {
+    return $this->getValue ("space-before-punctuation", "");
+  }
+  public function setCheckSpaceBeforePunctuation ($value) {
+    $this->setValue ("space-before-punctuation", $value);
+  }
+
+  public function getCheckSentenceStructure () {
+    return $this->getValue ("sentence-structure", "");
+  }
+  public function setCheckSentenceStructure ($value) {
+    $this->setValue ("sentence-structure", $value);
+  }
+
+  public function getSentenceStructureCapitals () {
+    return $this->getValue ("sentence-structure-capitals", "A B C D E F G H I J K L M N O P Q R S T U V W X Y Z");
+  }
+  public function setSentenceStructureCapitals ($value) {
+    $this->setValue ("sentence-structure-capitals", $value);
+  }
+
+  public function getSentenceStructureSmallLetters () {
+    return $this->getValue ("sentence-structure-small-letters", "a b c d e f g h i j k l m n o p q r s t u v w x y z");
+  }
+  public function setSentenceStructureSmallLetters ($value) {
+    $this->setValue ("sentence-structure-small-letters", $value);
+  }
+
+  public function getSentenceStructureEndPunctuation () {
+    return $this->getValue ("sentence-structure-end-punctuation", ". ! ? :");
+  }
+  public function setSentenceStructureEndPunctuation ($value) {
+    $this->setValue ("sentence-structure-end-punctuation", $value);
+  }
+
+  public function getSentenceStructureMiddlePunctuation () {
+    return $this->getValue ("sentence-structure-middle-punctuation", ", ;");
+  }
+  public function setSentenceStructureMiddlePunctuation ($value) {
+    $this->setValue ("sentence-structure-middle-punctuation", $value);
+  }
+
+  public function getSentenceStructureDisregards () {
+    return $this->getValue ("sentence-structure-disregards", "( ) [ ] { } ' \" * - 0 1 2 3 4 5 6 7 8 9");
+  }
+  public function setSentenceStructureDisregards ($value) {
+    $this->setValue ("sentence-structure-disregards", $value);
+  }
+
+  public function getSentenceStructureNames () {
+    return $this->getList ("sentence-structure-names", "");
+  }
+  public function setSentenceStructureNames ($value) {
+    $this->setList ("sentence-structure-names", $value);
   }
-  public function setSearchDaemonPort ($value) {
-    $this->setValue ("search-daemon-port", $value);
-  }   
 
 }
 
