@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -57,6 +57,7 @@ class Database_Notes
     return self::$instance;
   }
 
+
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE notes;");
@@ -71,6 +72,7 @@ class Database_Notes
     $result = $server->runQuery ($query);
     return ($result->num_rows > 0);
   }
+
   
   /**
   * Update a note's $identifier.
@@ -109,7 +111,6 @@ class Database_Notes
   }
   
 
-
   private function assembleContents ($identifier, $contents)
   {
     $new_contents = "";
@@ -161,8 +162,9 @@ class Database_Notes
     if (!$raw) $contents = $this->assembleContents ($identifier, $contents);
     $contents = Database_SQLInjection::no ($contents);
     if (($contents == "") && ($summary == "")) return;
-    $query = "INSERT INTO notes VALUES (NULL, $identifier, 0, '', '', '$bible', '$passage', 'New', 2, 0, '$summary', '$contents')";
+    $query = "INSERT INTO notes VALUES (NULL, $identifier, 0, '', '', '$bible', '$passage', 'New', 2, 0, '$summary', '$contents', NULL, NULL)";
     $server->runQuery ($query);
+    $this-> updateSearchFields ($identifier);
     $this->noteEditedActions ($identifier);
     // Return this new note´s identifier.
     return $identifier;
@@ -191,8 +193,16 @@ class Database_Notes
     $username = $session_logic->currentUser ();
     $identifiers = array ();
     $server = Database_Instance::getInstance ();
-    // Consider privacy setting.
-    $query = "SELECT identifier FROM notes WHERE private <= $userlevel ";
+    // SQL SELECT statement.
+    $query = Filter_Sql::notesSelectIdentifier ();
+    // SQL optional fulltext search statement sorted on relevance.
+    if ($text_selector == 1) {
+      $query .= Filter_Sql::notesOptionalFulltextSearchRelevanceStatement ($search_text);
+    }
+    // SQL FROM ... WHERE statement.
+    $query .= Filter_Sql::notesFromWhereStatement ();
+    // SQL privacy statement.
+    $query .= Filter_Sql::notesConsiderPrivacy ($userlevel);
     // Consider passage selector.
     switch ($passage_selector) {
       case 0:
@@ -294,10 +304,15 @@ class Database_Notes
     }
     // Consider text contained in notes.
     if ($text_selector == 1) {
-      $query .= " AND (MATCH (summary, contents) AGAINST ('$search_text' IN BOOLEAN MODE) OR summary LIKE '%$search_text%' OR CONTENTS LIKE '%$search_text%') ";
+      $query .= Filter_Sql::notesOptionalFulltextSearchStatement ($search_text);
+    }
+    if ($text_selector == 1) {
+      // If searching in fulltext mode, notes get ordered on relevance of search hits.
+      $query .= Filter_Sql::notesOrderByRelevanceStatement ();
+    } else {
+      // Notes get ordered by the passage they refer to. It is a rough method and better ordering is needed. 
+      $query .= " ORDER BY ABS (passage) ";
     }
-    // Notes get ordered by the passage they refer to. It is a rough method and better ordering is needed. 
-    $query .= " ORDER BY ABS(passage) ";
     // Limit the selection if a limit is given.
     if (is_numeric ($limit)) {
       $limit = Database_SQLInjection::no ($limit);
@@ -334,6 +349,7 @@ class Database_Notes
     $summary = Database_SQLInjection::no ($summary);
     $query = "UPDATE notes SET summary = '$summary' WHERE identifier = $identifier;";
     $server->runQuery ($query);
+    $this->updateSearchFields ($identifier);
   }
 
 
@@ -357,6 +373,7 @@ class Database_Notes
     $contents = Database_SQLInjection::no ($contents);
     $query = "UPDATE notes SET contents = '$contents' WHERE identifier = $identifier;";
     $server->runQuery ($query);
+    $this->updateSearchFields ($identifier);
   }
   
   
@@ -382,6 +399,7 @@ class Database_Notes
     $contents = Database_SQLInjection::no ($contents);
     $query = "UPDATE notes SET contents = '$contents' WHERE identifier = $identifier;";
     $server->runQuery ($query);
+    $this->updateSearchFields ($identifier);
     $this->noteEditedActions ($identifier);
   }
   
@@ -1037,16 +1055,83 @@ class Database_Notes
     }
     return $identifiers;
   }
+
+
+  public function updateSearchFields ($identifier)
+  {
+    // The search field is a combination of the summary and content converted to clean text.
+    // Another search field will contain the reversed clean text.
+    // Both fields together enable us to search with wildcards before and after the search query
+    // with MySQL fulltext search in boolean mode.
+    $noteSummary = $this->getSummary ($identifier);
+    $noteContents = $this->getContents ($identifier);
+    $cleanText = $noteSummary . "\n" . Filter_Html::html2text ($noteContents);
+    $reversedText = Filter_String::reverse ($cleanText);
+    $cleanText = Database_SQLInjection::no ($cleanText);
+    $reversedText = Database_SQLInjection::no ($reversedText);
+    $server = Database_Instance::getInstance ();
+    $query = "UPDATE notes SET cleantext = '$cleanText' WHERE identifier = $identifier;";
+    $server->runQuery ($query);
+    $query = "UPDATE notes SET reversedtext = '$reversedText' WHERE identifier = $identifier;";
+    $server->runQuery ($query);
+  }
+
+
+  public function getSearchField ($identifier)
+  {
+    $server = Database_Instance::getInstance ();
+    $identifier = Database_SQLInjection::no ($identifier);
+    $query = "SELECT cleantext FROM notes WHERE identifier = $identifier;";
+    $result = $server->runQuery ($query);
+    if ($result->num_rows > 0) {
+      $row = $result->fetch_row();
+      return $row[0];
+    }
+    return "";
+  }
   
   
-
-
-
-
+  /**
+  * Searches the notes.
+  * Returns an array of note identifiers.
+  * If $limit is non-NULL, it indicates the starting limit for the selection.
+  * $search: Contains the text to search for.
+  */
+  public function searchNotes ($search, $limit = NULL)
+  {
+    $identifiers = array ();
+    $server = Database_Instance::getInstance ();
+    // SQL SELECT statement.
+    $query = Filter_Sql::notesSelectIdentifier ();
+    // SQL fulltext search statement sorted on relevance.
+    $query .= Filter_Sql::notesOptionalFulltextSearchRelevanceStatement ($search);
+    // SQL FROM ... WHERE statement.
+    $query .= Filter_Sql::notesFromWhereStatement ();
+    // SQL privacy statement.
+    $session_logic = Session_Logic::getInstance ();
+    $userlevel = $session_logic->currentLevel ();
+    $query .= Filter_Sql::notesConsiderPrivacy ($userlevel);
+    // Consider text contained in notes.
+    $query .= Filter_Sql::notesOptionalFulltextSearchStatement ($search);
+    // Notes get ordered on relevance of search hits.
+    $query .= Filter_Sql::notesOrderByRelevanceStatement ();
+    // Limit the selection if a limit is given.
+    if (is_numeric ($limit)) {
+      $limit = Database_SQLInjection::no ($limit);
+      $query .= " LIMIT $limit, 50 ";
+    }
+    $query .= ";";
+    $result = $server->runQuery ($query);
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $identifier = $row[0];
+      $identifiers []= $identifier;
+    }
+    return $identifiers;
+  }
+  
   
-
 }
 
 
-
 ?>
