@@ -5,7 +5,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -637,7 +637,7 @@ class Odf_Text
     $string = $this->stylesDom->save ($this->unpackedOdtFolder . "/styles.xml");
 
     // Save the OpenDocument file.    
-    $zippedfile = Filter_Archive::zipFolder ($this->unpackedOdtFolder, false);
+    $zippedfile = Filter_Archive::zip ($this->unpackedOdtFolder);
     file_put_contents ($name, file_get_contents ($zippedfile));
     unlink ($zippedfile);
   }
@@ -712,4 +712,4 @@ class Odf_Text
 }
 
 
-?>
\ No newline at end of file
+?>
