@@ -20,18 +20,10 @@ if (isset($_POST['submit'])) {
   }
   if ($form_is_valid) {
     $session_logic = Session_Logic::getInstance ();
+    $database_logs = Database_Logs::getInstance ();
     if ($session_logic->attemptLogin ($user, $pass)) {
-      // If a non-admin logs in, send admin mail.
-      $mail = Database_Mail::getInstance ();
-      $users = Database_Users::getInstance ();
-      $admin = $users->getAdministrator ();
-      $subject = $session_logic->currentUser () . " logged in";
-      // Admins should not be notified if admins login. If it would be done, then each time an admin logs in,
-      // he would be greeted with a message saying that there is mail for him. This one mail would be his own login notification.
-      include ("session/levels.php");
-      if ($session_logic->currentLevel (true) != ADMIN_LEVEL) {
-        $mail->send ($admin, $subject, "");
-      }
+      // Log the login.
+      $database_logs->log ($session_logic->currentUser () . " logged in");
       // Store web site's base URL.
       $database_config_general = Database_Config_General::getInstance ();
       @$siteUrl = dirname (dirname ($_SERVER["HTTP_REFERER"]));
@@ -39,13 +31,8 @@ if (isset($_POST['submit'])) {
     } else {
       $smarty->assign ('error_message', gettext ("Username or email address or password are not correct"));
       $session_logic->logout();
-      // Inform administrator about the login failure.
-      $mail = Database_Mail::getInstance ();
-      $users = Database_Users::getInstance ();
-      $admin = $users->getAdministrator ();
-      $subject = "Failed login attempt";
-      $body = "Failed login attempt for user $user with password $pass";
-      $mail->send ($admin, $subject, $body);
+      // Log the login failure.
+      $database_logs->log ("Failed login attempt for user $user with password $pass");
     }
   }
 }
@@ -61,4 +48,4 @@ if ($session_logic->loggedIn ()) {
   $smarty->display("login.tpl");
 }
 
-?>
\ No newline at end of file
+?>
