@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -34,6 +34,11 @@ if (php_sapi_name () != "cli") {
 }
 
 
+// Newer git versions would read their config from /root and then generate a fatal error.
+// Fix that here by setting the $HOME variable to something git can read.
+putenv ("HOME=" . dirname (__FILE__));
+
+
 $database_logs->log ("send/receive: Processing any data left over from previous actions");
 Filter_Git::filedata2database ();
 
@@ -266,4 +271,4 @@ $database_logs->log ("send/receive: **********");
 $database_logs->log ("send/receive: Ready");
 
 
-?>
\ No newline at end of file
+?>
